Simulation Physics
==================

.. _physics_model:

.. automodule:: pyfrc.physics.core
   :members:

Drivetrain support
------------------

.. automodule:: pyfrc.physics.drivetrains
   :members:

Motor configurations
--------------------

.. automodule:: pyfrc.physics.motor_cfgs
  :members:

Motion support
--------------

.. automodule:: pyfrc.physics.motion
   :members:

Tank drive model support
------------------------

.. automodule:: pyfrc.physics.tankmodel
   :members:

.. _units:

Unit conversions
----------------

.. automodule:: pyfrc.physics.units
   :members:

Camera 'simulator'
------------------

.. automodule:: pyfrc.physics.visionsim
   :members:
